@@ -1,6 +1,6 @@
 /* lid.c -- primary query interface for mkid database
-   Copyright (C) 1986, 1995-1996, 1999-2000, 2007-2009 Free Software Foundation,
-   Inc.
+   Copyright (C) 1986, 1995-1996, 1999-2000, 2007-2010 Free Software
+   Foundation, Inc.
    Written by Greg McGary <gkm@gnu.ai.mit.edu>
 
    This program is free software; you can redistribute it and/or modify
@@ -1512,9 +1512,7 @@ static struct termios savemode;
 
 #else /* not HAVE_TERMIOS_H */
 
-# if HAVE_SYS_IOCTL_H
-#  include <sys/ioctl.h>
-# endif
+#include <sys/ioctl.h>
 
 # if HAVE_TERMIO_H
 
